==> deldir_0.1-7.tar.gz: deldir/man/tile.list.Rd <==
\name{tile.list}
\alias{tile.list}
\title{ Create a list of tiles in a tessellation }
\description{
For each point in the set being tessellated produces a list
entry describing the Dirichlet/Voronoi tile containing that
point.
}
\usage{ tile.list(object) }
\arguments{
  \item{object}{ An object of class \code{deldir} as produced
   by the function \code{\link{deldir}()}.}
}
\value{
A list with one entry for each of the points in the set
being tesselated.  Each entry is in turn a list with
components

\item{pt}{The coordinates of the point whose tile is being described.}
\item{x}{The \code{x} coordinates of the vertices of the tile, in
anticlockwise order.}
\item{y}{The \code{y} coordinates of the vertices of the tile, in
anticlockwise order.}
\item{bp}{Vector of logicals indicating whether the tile vertex is a
``real'' vertex, or a \emph{boundary point}, i.e. a point where the
tile edge intersects the boundary of the enclosing rectangle}
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
  \url{http://www.stat.auckland.ac.nz/~rolf}
}
\section{Acknowledgement}{
The author expresses sincere thanks to Majid Yazdani who found and
pointed out a serious bug in \code{tile.list} in a previous version
(0.0-5) of the \code{deldir} package.
}

\section{Warning}{
The set of vertices of each tile may be ``incomplete''.  Only
vertices which lie within the enclosing rectangle, and ``boundary
points'' are listed.

Note that the enclosing rectangle may be specified by the user
in the call to \code{\link{deldir}()}.

In contrast to some earlier versions of \code{deldir}, the corners
of the enclosing rectangle are now include as vertices of tiles.
I.e. a tile which in fact extends beyond the rectangular window
and contains a corner of that window will have that corner added
to its list of vertices.  Thus the corresponding polygon is the
intersection of the tile with the enclosing rectangle.
}

\seealso{ \code{\link{deldir}()}, \code{\link{plot.tile.list}()}
          \code{\link{triang.list}()} \code{\link{plot.triang.list}()} }

\examples{
	x <- runif(20)
	y <- runif(20)
	z <- deldir(x,y)
	w <- tile.list(z)

	z <- deldir(x,y,rw=c(0,1,0,1))
	w <- tile.list(z)

	z <- deldir(x,y,rw=c(0,1,0,1),dpl=list(ndx=2,ndy=2))
	w <- tile.list(z)

}
\keyword{spatial}

==> deldir_0.1-28.tar.gz: deldir/man/tile.list.Rd <==
\name{tile.list}
\alias{tile.list}
\title{ Create a list of tiles in a tessellation }
\description{
For each point in the set being tessellated produces a list
entry describing the Dirichlet/Voronoi tile containing that
point.
}
\usage{ tile.list(object,minEdgeLength=NULL) }
\arguments{
  \item{object}{ An object of class \code{deldir} as produced
   by the function \code{\link{deldir}()}.}
  \item{minEdgeLength}{
  Positive numeric scalar specifying the minimum length that
  an edge of a tile may have.  It is used to eliminate edges
  that are effectively of zero length, which can cause tiles
  to be \dQuote{invalid}.  This argument defaults to
  \code{sqrt(.Machine$double.eps)} time the diameter (length
  of the diagonal) of the \dQuote{rectangular window}
  associated with the tessellation.  This rectangular window
  is available as the \code{rw} component of \code{object}.
}
}
\value{
A list with one entry for each of the points in the set
being tesselated.  Each entry is in turn a list with
components

\item{ptNum}{The index of the point in the original sequence of points
that is being tessellated.  Note that if a point is one of a set
of \emph{duplicated} points then \code{ptNum} is the \emph{first} of the
indices of the points in this set.}
\item{pt}{The coordinates of the point whose tile is being described.}
\item{ptType}{The \dQuote{type} of the \code{pt}, either \dQuote{data}
or \dQuote{dummy}.  Present only if any dummy points were specified
in the call to \code{deldir()}.}
\item{x}{The \code{x} coordinates of the vertices of the tile, in
anticlockwise order.}
\item{y}{The \code{y} coordinates of the vertices of the tile, in
anticlockwise order.}
\item{bp}{Vector of logicals indicating whether the tile vertex is a
``real'' vertex, or a \emph{boundary point}, i.e. a point where the
tile edge intersects the boundary of the enclosing rectangle.}
\item{z}{The \dQuote{auxiliary value} or \dQuote{weight} associated
with the \code{pt}; present only if such values were supplied in
the call to \code{deldir()}.}
\item{area}{The area of the tile.}
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
% \url{https://www.stat.auckland.ac.nz/~rolf}
}
\section{Acknowledgement}{
The author expresses sincere thanks to Majid Yazdani who found and
pointed out a serious bug in \code{tile.list} in a previous version
(0.0-5) of the \code{deldir} package.
}

\section{Warning}{
The set of vertices of each tile may be ``incomplete''.  Only
vertices which lie within the enclosing rectangle, and ``boundary
points'' are listed.

Note that the enclosing rectangle may be specified by the user
in the call to \code{\link{deldir}()}.

In contrast to some earlier versions of \code{deldir}, the corners
of the enclosing rectangle are now include as vertices of tiles.
I.e. a tile which in fact extends beyond the rectangular window
and contains a corner of that window will have that corner added
to its list of vertices.  Thus the corresponding polygon is the
intersection of the tile with the enclosing rectangle.
}

\seealso{ \code{\link{deldir}()}, \code{\link{plot.tile.list}()}
          \code{\link{triang.list}()} \code{\link{plot.triang.list}()} }

\examples{
	x <- runif(20)
	y <- runif(20)
	z <- deldir(x,y)
	w <- tile.list(z)

	z <- deldir(x,y,rw=c(0,1,0,1))
	w <- tile.list(z)

	z <- deldir(x,y,rw=c(0,1,0,1),dpl=list(ndx=2,ndy=2))
	w <- tile.list(z)

}
\keyword{spatial}
